# Generated by Django 4.1.2 on 2022-11-20 21:08

import _socket
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_crypto_fields.fields.encrypted_text_field
import django_revision.revision_field
import edc_action_item.managers
import edc_identifier.managers
import edc_model.models.fields.other_charfield
import edc_model.validators.date
import edc_protocol.validators
import edc_sites.models
import edc_utils.date
import simple_history.models
import uuid


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("intecomm_lists", "0001_initial"),
        ("sites", "0002_alter_domain_unique"),
        ("edc_action_item", "0031_auto_20220922_2236"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("edc_protocol_incident", "0001_squashed_0015_auto_20220927_0401"),
    ]

    operations = [
        migrations.CreateModel(
            name="SubjectTransfer",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "action_identifier",
                    models.CharField(blank=True, max_length=50, null=True, unique=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        verbose_name="Report Date and Time",
                    ),
                ),
                (
                    "transfer_date",
                    models.DateField(
                        default=edc_utils.date.get_utcnow, verbose_name="Transfer date"
                    ),
                ),
                (
                    "initiated_by",
                    models.CharField(
                        choices=[
                            ("patient", "Patient"),
                            ("clinician", "Attending Clinician / Healthcare worker"),
                            ("OTHER", "Other"),
                        ],
                        max_length=25,
                        verbose_name="Who initiated the transfer request",
                    ),
                ),
                (
                    "initiated_by_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "transfer_reason_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "may_return",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("not_sure", "Not sure"),
                        ],
                        max_length=15,
                        verbose_name="Is the participant likely to transfer back before the end of their stay in the trial?",
                    ),
                ),
                (
                    "may_contact",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Is the participant willing to be contacted at the end of the study?",
                    ),
                ),
                (
                    "comment",
                    django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                        blank=True,
                        help_text=" (Encryption: AES local)",
                        max_length=71,
                        verbose_name="Additional Comments",
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "transfer_reason",
                    models.ManyToManyField(
                        to="intecomm_lists.transferreasons",
                        verbose_name="Reason for transfer",
                    ),
                ),
            ],
            options={
                "verbose_name": "Subject Transfer",
                "verbose_name_plural": "Subject Transfers",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.CreateModel(
            name="ProtocolIncident",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50)),
                (
                    "action_identifier",
                    models.CharField(blank=True, max_length=50, null=True, unique=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        verbose_name="Report Date and Time",
                    ),
                ),
                (
                    "short_description",
                    models.CharField(
                        help_text="Max 35 characters. Note: there is additional space below for a more detailed description",
                        max_length=35,
                        null=True,
                        verbose_name="Provide a short description of this incident",
                    ),
                ),
                (
                    "report_type",
                    models.CharField(
                        choices=[
                            ("protocol_violation", "Protocol violation"),
                            ("protocol_deviation", "Protocol deviation"),
                        ],
                        max_length=25,
                        verbose_name="Type of incident",
                    ),
                ),
                (
                    "safety_impact",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Could this incident have an impact on safety of the participant?",
                    ),
                ),
                (
                    "safety_impact_details",
                    models.TextField(
                        blank=True, null=True, verbose_name='If "Yes", provide details'
                    ),
                ),
                (
                    "study_outcomes_impact",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Could this incident have an impact on study outcomes?",
                    ),
                ),
                (
                    "study_outcomes_impact_details",
                    models.TextField(
                        blank=True, null=True, verbose_name='If "Yes", provide details'
                    ),
                ),
                (
                    "incident_datetime",
                    models.DateTimeField(
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date incident occurred",
                    ),
                ),
                (
                    "incident_other",
                    models.CharField(
                        blank=True,
                        max_length=75,
                        null=True,
                        verbose_name="If other, please specify",
                    ),
                ),
                (
                    "incident_description",
                    models.TextField(
                        help_text="Describe in full. Explain how the incident happened, what occurred, etc.",
                        null=True,
                        verbose_name="Describe the incident",
                    ),
                ),
                (
                    "incident_reason",
                    models.TextField(
                        null=True,
                        verbose_name="Explain the reason why the incident occurred",
                    ),
                ),
                (
                    "corrective_action_datetime",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Corrective action date and time",
                    ),
                ),
                (
                    "corrective_action",
                    models.TextField(
                        blank=True, null=True, verbose_name="Corrective action taken"
                    ),
                ),
                (
                    "preventative_action_datetime",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Preventative action date and time",
                    ),
                ),
                (
                    "preventative_action",
                    models.TextField(
                        blank=True, null=True, verbose_name="Preventative action taken"
                    ),
                ),
                (
                    "report_status",
                    models.CharField(
                        choices=[
                            ("open", "Open. Some information is still pending."),
                            ("closed", "Closed. This report is complete"),
                        ],
                        max_length=25,
                        verbose_name="What is the status of this report?",
                    ),
                ),
                (
                    "report_closed_datetime",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date and time report closed.",
                    ),
                ),
                (
                    "action_required_old",
                    models.CharField(
                        choices=[
                            ("remain_on_study", "Participant to remain on trial"),
                            (
                                "to_be_withdrawn",
                                "Participant to be withdrawn from trial",
                            ),
                            (
                                "remain_on_study_modified",
                                "Patient remains on study but data analysis will be modified",
                            ),
                        ],
                        max_length=45,
                        null=True,
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="intecomm_prn_action_item",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "action_required",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_protocol_incident.actionsrequired",
                    ),
                ),
                (
                    "incident",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_protocol_incident.protocolviolations",
                        verbose_name="Type of incident",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Protocol Incident",
                "verbose_name_plural": "Protocol Incident",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.CreateModel(
            name="OnScheduleFollowup",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "onschedule_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False)),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_identifier.managers.SubjectIdentifierManager()),
            ],
        ),
        migrations.CreateModel(
            name="OnScheduleBaseline",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "onschedule_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False)),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_identifier.managers.SubjectIdentifierManager()),
            ],
        ),
        migrations.CreateModel(
            name="OffScheduleFollowup",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "action_identifier",
                    models.CharField(blank=True, max_length=50, null=True, unique=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "offschedule_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Date and time subject taken off schedule",
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False)),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Off-schedule Followup",
                "verbose_name_plural": "Off-schedule Followup",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.CreateModel(
            name="OffScheduleBaseline",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "action_identifier",
                    models.CharField(blank=True, max_length=50, null=True, unique=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "offschedule_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Date and time subject taken off schedule",
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False)),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Off-schedule",
                "verbose_name_plural": "Off-schedule",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.CreateModel(
            name="LossToFollowup",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50)),
                (
                    "action_identifier",
                    models.CharField(blank=True, max_length=50, null=True, unique=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        verbose_name="Report Date and Time",
                    ),
                ),
                (
                    "last_seen_datetime",
                    models.DateField(verbose_name="Date participant last seen"),
                ),
                (
                    "number_consecutive_missed_visits",
                    models.DateField(
                        null=True, verbose_name="Number of consecutive visits missed"
                    ),
                ),
                (
                    "last_missed_visit_datetime",
                    models.DateField(
                        null=True,
                        verbose_name="Date of last missed visit report submitted",
                    ),
                ),
                (
                    "home_visited",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Has a home visit been made",
                    ),
                ),
                (
                    "home_visit_detail",
                    models.TextField(
                        null=True,
                        verbose_name="If YES, provide any further details of the home visit",
                    ),
                ),
                (
                    "loss_category",
                    models.CharField(
                        choices=[
                            ("unknown_address", "Changed to an unknown address"),
                            ("never_returned", "Did not return despite reminders"),
                            ("bad_contact_details", "Inaccurate contact details"),
                            ("OTHER", "Other, please specify ..."),
                        ],
                        max_length=25,
                        verbose_name="Category of loss to follow up",
                    ),
                ),
                (
                    "loss_category_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "comment",
                    models.TextField(
                        null=True,
                        verbose_name="Please give details of the circumstances that have led to this decision.",
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Loss to Follow Up",
                "verbose_name_plural": "Loss to Follow Up",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.CreateModel(
            name="HistoricalSubjectTransfer",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "action_identifier",
                    models.CharField(blank=True, db_index=True, max_length=50, null=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        verbose_name="Report Date and Time",
                    ),
                ),
                (
                    "transfer_date",
                    models.DateField(
                        default=edc_utils.date.get_utcnow, verbose_name="Transfer date"
                    ),
                ),
                (
                    "initiated_by",
                    models.CharField(
                        choices=[
                            ("patient", "Patient"),
                            ("clinician", "Attending Clinician / Healthcare worker"),
                            ("OTHER", "Other"),
                        ],
                        max_length=25,
                        verbose_name="Who initiated the transfer request",
                    ),
                ),
                (
                    "initiated_by_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "transfer_reason_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "may_return",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("not_sure", "Not sure"),
                        ],
                        max_length=15,
                        verbose_name="Is the participant likely to transfer back before the end of their stay in the trial?",
                    ),
                ),
                (
                    "may_contact",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Is the participant willing to be contacted at the end of the study?",
                    ),
                ),
                (
                    "comment",
                    django_crypto_fields.fields.encrypted_text_field.EncryptedTextField(
                        blank=True,
                        help_text=" (Encryption: AES local)",
                        max_length=71,
                        verbose_name="Additional Comments",
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Subject Transfer",
                "verbose_name_plural": "historical Subject Transfers",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalProtocolIncident",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50)),
                (
                    "action_identifier",
                    models.CharField(blank=True, db_index=True, max_length=50, null=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        verbose_name="Report Date and Time",
                    ),
                ),
                (
                    "short_description",
                    models.CharField(
                        help_text="Max 35 characters. Note: there is additional space below for a more detailed description",
                        max_length=35,
                        null=True,
                        verbose_name="Provide a short description of this incident",
                    ),
                ),
                (
                    "report_type",
                    models.CharField(
                        choices=[
                            ("protocol_violation", "Protocol violation"),
                            ("protocol_deviation", "Protocol deviation"),
                        ],
                        max_length=25,
                        verbose_name="Type of incident",
                    ),
                ),
                (
                    "safety_impact",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Could this incident have an impact on safety of the participant?",
                    ),
                ),
                (
                    "safety_impact_details",
                    models.TextField(
                        blank=True, null=True, verbose_name='If "Yes", provide details'
                    ),
                ),
                (
                    "study_outcomes_impact",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Could this incident have an impact on study outcomes?",
                    ),
                ),
                (
                    "study_outcomes_impact_details",
                    models.TextField(
                        blank=True, null=True, verbose_name='If "Yes", provide details'
                    ),
                ),
                (
                    "incident_datetime",
                    models.DateTimeField(
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date incident occurred",
                    ),
                ),
                (
                    "incident_other",
                    models.CharField(
                        blank=True,
                        max_length=75,
                        null=True,
                        verbose_name="If other, please specify",
                    ),
                ),
                (
                    "incident_description",
                    models.TextField(
                        help_text="Describe in full. Explain how the incident happened, what occurred, etc.",
                        null=True,
                        verbose_name="Describe the incident",
                    ),
                ),
                (
                    "incident_reason",
                    models.TextField(
                        null=True,
                        verbose_name="Explain the reason why the incident occurred",
                    ),
                ),
                (
                    "corrective_action_datetime",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Corrective action date and time",
                    ),
                ),
                (
                    "corrective_action",
                    models.TextField(
                        blank=True, null=True, verbose_name="Corrective action taken"
                    ),
                ),
                (
                    "preventative_action_datetime",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Preventative action date and time",
                    ),
                ),
                (
                    "preventative_action",
                    models.TextField(
                        blank=True, null=True, verbose_name="Preventative action taken"
                    ),
                ),
                (
                    "report_status",
                    models.CharField(
                        choices=[
                            ("open", "Open. Some information is still pending."),
                            ("closed", "Closed. This report is complete"),
                        ],
                        max_length=25,
                        verbose_name="What is the status of this report?",
                    ),
                ),
                (
                    "report_closed_datetime",
                    models.DateTimeField(
                        blank=True,
                        null=True,
                        validators=[edc_model.validators.date.datetime_not_future],
                        verbose_name="Date and time report closed.",
                    ),
                ),
                (
                    "action_required_old",
                    models.CharField(
                        choices=[
                            ("remain_on_study", "Participant to remain on trial"),
                            (
                                "to_be_withdrawn",
                                "Participant to be withdrawn from trial",
                            ),
                            (
                                "remain_on_study_modified",
                                "Patient remains on study but data analysis will be modified",
                            ),
                        ],
                        max_length=45,
                        null=True,
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "action_required",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_protocol_incident.actionsrequired",
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "incident",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_protocol_incident.protocolviolations",
                        verbose_name="Type of incident",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Protocol Incident",
                "verbose_name_plural": "historical Protocol Incident",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalOnScheduleFollowup",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "onschedule_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical on schedule followup",
                "verbose_name_plural": "historical on schedule followups",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalOnScheduleBaseline",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "onschedule_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical on schedule baseline",
                "verbose_name_plural": "historical on schedule baselines",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalOffScheduleFollowup",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "action_identifier",
                    models.CharField(blank=True, db_index=True, max_length=50, null=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "offschedule_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Date and time subject taken off schedule",
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False)),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Off-schedule Followup",
                "verbose_name_plural": "historical Off-schedule Followup",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalOffScheduleBaseline",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "action_identifier",
                    models.CharField(blank=True, db_index=True, max_length=50, null=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "offschedule_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Date and time subject taken off schedule",
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False)),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Off-schedule",
                "verbose_name_plural": "historical Off-schedule",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalLossToFollowup",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50)),
                (
                    "action_identifier",
                    models.CharField(blank=True, db_index=True, max_length=50, null=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        verbose_name="Report Date and Time",
                    ),
                ),
                (
                    "last_seen_datetime",
                    models.DateField(verbose_name="Date participant last seen"),
                ),
                (
                    "number_consecutive_missed_visits",
                    models.DateField(
                        null=True, verbose_name="Number of consecutive visits missed"
                    ),
                ),
                (
                    "last_missed_visit_datetime",
                    models.DateField(
                        null=True,
                        verbose_name="Date of last missed visit report submitted",
                    ),
                ),
                (
                    "home_visited",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Has a home visit been made",
                    ),
                ),
                (
                    "home_visit_detail",
                    models.TextField(
                        null=True,
                        verbose_name="If YES, provide any further details of the home visit",
                    ),
                ),
                (
                    "loss_category",
                    models.CharField(
                        choices=[
                            ("unknown_address", "Changed to an unknown address"),
                            ("never_returned", "Did not return despite reminders"),
                            ("bad_contact_details", "Inaccurate contact details"),
                            ("OTHER", "Other, please specify ..."),
                        ],
                        max_length=25,
                        verbose_name="Category of loss to follow up",
                    ),
                ),
                (
                    "loss_category_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "comment",
                    models.TextField(
                        null=True,
                        verbose_name="Please give details of the circumstances that have led to this decision.",
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Loss to Follow Up",
                "verbose_name_plural": "historical Loss to Follow Up",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HistoricalEndOfStudy",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                ("subject_identifier", models.CharField(db_index=True, max_length=50)),
                (
                    "action_identifier",
                    models.CharField(blank=True, db_index=True, max_length=50, null=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "offstudy_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Off-study date and time",
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False, null=True)),
                (
                    "last_seen_date",
                    models.DateField(
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date patient was last seen",
                    ),
                ),
                (
                    "other_offstudy_reason",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="If OTHER, please specify",
                    ),
                ),
                (
                    "ltfu_date",
                    models.DateField(
                        blank=True,
                        help_text="A Loss to followup report must be on file",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date lost to followup, if applicable",
                    ),
                ),
                (
                    "death_date",
                    models.DateField(
                        blank=True,
                        help_text="A Death report must be on file",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date of death, if applicable",
                    ),
                ),
                (
                    "pregnancy_date",
                    models.DateField(
                        blank=True,
                        help_text="A UPT CRF must be on file and participant not on the delivery schedule. Use UPT date or, if UPT not needed, use report date on last UPT CRF.",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date pregnancy known/UPT, if applicable",
                    ),
                ),
                (
                    "delivery_date",
                    models.DateField(
                        blank=True,
                        help_text="A Delivery CRF must be on file. Use delivery date, if reported, or report date from Delivery CRF",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date of delivery, if applicable",
                    ),
                ),
                (
                    "clinical_withdrawal_reason",
                    models.CharField(
                        choices=[
                            ("kidney_disease", "Development of chronic kidney disease"),
                            ("liver_disease", "Development of chronic liver disease"),
                            (
                                "intercurrent_illness",
                                "Intercurrent illness which prevents further treatment",
                            ),
                            (
                                "investigator_decision",
                                "Investigator decision (specify below)",
                            ),
                            (
                                "OTHER",
                                "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                            ),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="If the patient was withdrawn on CLINICAL grounds, please specify PRIMARY reason",
                    ),
                ),
                (
                    "clinical_withdrawal_reason_other",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="If withdrawn for 'other' condition, please explain",
                    ),
                ),
                (
                    "clinical_withdrawal_investigator_decision",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="If withdrawl was an 'investigator decision', please explain ...",
                    ),
                ),
                (
                    "toxicity_withdrawal_reason",
                    models.CharField(
                        choices=[
                            (
                                "lactic_acidosis",
                                "Development of lactic acidosis or hyperlactatemia",
                            ),
                            (
                                "hepatomegaly",
                                "Development of hepatomegaly with steatosis",
                            ),
                            ("OTHER", "Other toxicity (specify below)"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name=" If the patient experienced an unacceptable toxicity', please explain",
                    ),
                ),
                (
                    "toxicity_withdrawal_reason_other",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="If 'other toxicity', please specify ...",
                    ),
                ),
                (
                    "transfer_date",
                    models.DateField(
                        blank=True,
                        help_text="A Transfer form must be on file.",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date of transfer, if applicable",
                    ),
                ),
                (
                    "transferred_consent",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="If transferred, has the patient provided consent to be followed-up?",
                    ),
                ),
                (
                    "comment",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="Please provide further details if possible",
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "offstudy_reason",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        limit_choices_to={
                            "name__in": [
                                "clinical_withdrawal",
                                "completed_followup",
                                "dead",
                                "delivery",
                                "diabetes",
                                "late_exclusion",
                                "LTFU",
                                "OTHER",
                                "pregnancy",
                                "toxicity",
                                "transferred",
                                "withdrawal",
                            ]
                        },
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="intecomm_lists.offstudyreasons",
                        verbose_name="Reason patient was terminated from the study",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical End of Study",
                "verbose_name_plural": "historical End of Study",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="EndOfStudy",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("subject_identifier", models.CharField(max_length=50, unique=True)),
                (
                    "action_identifier",
                    models.CharField(blank=True, max_length=50, null=True, unique=True),
                ),
                (
                    "parent_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to parent reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                (
                    "related_action_identifier",
                    models.CharField(
                        blank=True,
                        help_text="action identifier that links to related reference model instance.",
                        max_length=30,
                        null=True,
                    ),
                ),
                ("action_item_reason", models.TextField(editable=False, null=True)),
                (
                    "offstudy_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Off-study date and time",
                    ),
                ),
                ("report_datetime", models.DateTimeField(editable=False, null=True)),
                (
                    "last_seen_date",
                    models.DateField(
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date patient was last seen",
                    ),
                ),
                (
                    "other_offstudy_reason",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="If OTHER, please specify",
                    ),
                ),
                (
                    "ltfu_date",
                    models.DateField(
                        blank=True,
                        help_text="A Loss to followup report must be on file",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date lost to followup, if applicable",
                    ),
                ),
                (
                    "death_date",
                    models.DateField(
                        blank=True,
                        help_text="A Death report must be on file",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date of death, if applicable",
                    ),
                ),
                (
                    "pregnancy_date",
                    models.DateField(
                        blank=True,
                        help_text="A UPT CRF must be on file and participant not on the delivery schedule. Use UPT date or, if UPT not needed, use report date on last UPT CRF.",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date pregnancy known/UPT, if applicable",
                    ),
                ),
                (
                    "delivery_date",
                    models.DateField(
                        blank=True,
                        help_text="A Delivery CRF must be on file. Use delivery date, if reported, or report date from Delivery CRF",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date of delivery, if applicable",
                    ),
                ),
                (
                    "clinical_withdrawal_reason",
                    models.CharField(
                        choices=[
                            ("kidney_disease", "Development of chronic kidney disease"),
                            ("liver_disease", "Development of chronic liver disease"),
                            (
                                "intercurrent_illness",
                                "Intercurrent illness which prevents further treatment",
                            ),
                            (
                                "investigator_decision",
                                "Investigator decision (specify below)",
                            ),
                            (
                                "OTHER",
                                "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                            ),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name="If the patient was withdrawn on CLINICAL grounds, please specify PRIMARY reason",
                    ),
                ),
                (
                    "clinical_withdrawal_reason_other",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="If withdrawn for 'other' condition, please explain",
                    ),
                ),
                (
                    "clinical_withdrawal_investigator_decision",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="If withdrawl was an 'investigator decision', please explain ...",
                    ),
                ),
                (
                    "toxicity_withdrawal_reason",
                    models.CharField(
                        choices=[
                            (
                                "lactic_acidosis",
                                "Development of lactic acidosis or hyperlactatemia",
                            ),
                            (
                                "hepatomegaly",
                                "Development of hepatomegaly with steatosis",
                            ),
                            ("OTHER", "Other toxicity (specify below)"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=25,
                        verbose_name=" If the patient experienced an unacceptable toxicity', please explain",
                    ),
                ),
                (
                    "toxicity_withdrawal_reason_other",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="If 'other toxicity', please specify ...",
                    ),
                ),
                (
                    "transfer_date",
                    models.DateField(
                        blank=True,
                        help_text="A Transfer form must be on file.",
                        null=True,
                        validators=[edc_model.validators.date.date_not_future],
                        verbose_name="Date of transfer, if applicable",
                    ),
                ),
                (
                    "transferred_consent",
                    models.CharField(
                        choices=[
                            ("Yes", "Yes"),
                            ("No", "No"),
                            ("N/A", "Not applicable"),
                        ],
                        default="N/A",
                        max_length=15,
                        verbose_name="If transferred, has the patient provided consent to be followed-up?",
                    ),
                ),
                (
                    "comment",
                    models.TextField(
                        blank=True,
                        max_length=500,
                        null=True,
                        verbose_name="Please provide further details if possible",
                    ),
                ),
                (
                    "action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "offstudy_reason",
                    models.ForeignKey(
                        limit_choices_to={
                            "name__in": [
                                "clinical_withdrawal",
                                "completed_followup",
                                "dead",
                                "delivery",
                                "diabetes",
                                "late_exclusion",
                                "LTFU",
                                "OTHER",
                                "pregnancy",
                                "toxicity",
                                "transferred",
                                "withdrawal",
                            ]
                        },
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="intecomm_lists.offstudyreasons",
                        verbose_name="Reason patient was terminated from the study",
                    ),
                ),
                (
                    "parent_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "related_action_item",
                    models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_action_item.actionitem",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "End of Study",
                "verbose_name_plural": "End of Study",
                "abstract": False,
            },
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
            ],
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "site", "id"],
                name="intecomm_pr_subject_73a582_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulefollowup",
            index=models.Index(
                fields=["id", "subject_identifier", "onschedule_datetime", "site"],
                name="intecomm_pr_id_a4d7d5_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulebaseline",
            index=models.Index(
                fields=["id", "subject_identifier", "onschedule_datetime", "site"],
                name="intecomm_pr_id_52a218_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulefollowup",
            index=models.Index(
                fields=["id", "subject_identifier", "offschedule_datetime", "site"],
                name="intecomm_pr_id_b1c9bc_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulebaseline",
            index=models.Index(
                fields=["id", "subject_identifier", "offschedule_datetime", "site"],
                name="intecomm_pr_id_829ea5_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "site", "id"],
                name="intecomm_pr_subject_e91aac_idx",
            ),
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-05 20:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0013_endofstudy_locale_created_endofstudy_locale_modified_and_more"),
    ]

    operations = [
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__f3bf58_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_f05824_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_89a34d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "site", "id"],
                name="intecomm_pr_subject_96eaef_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_pr_subject_9a445d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__415159_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_dbd0f3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_f0e202_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["subject_identifier", "offschedule_datetime", "site"],
                name="intecomm_pr_subject_51b057_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__c60fdc_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_946b96_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_593cbf_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=[
                    "id",
                    "subject_identifier",
                    "action_identifier",
                    "offschedule_datetime",
                    "site",
                ],
                name="intecomm_pr_id_674324_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["subject_identifier", "offschedule_datetime", "site"],
                name="intecomm_pr_subject_86628b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__3f16f3_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_673c82_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_8df27b_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=[
                    "id",
                    "subject_identifier",
                    "action_identifier",
                    "offschedule_datetime",
                    "site",
                ],
                name="intecomm_pr_id_2e2c54_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["subject_identifier", "onschedule_datetime", "site"],
                name="intecomm_pr_subject_63aaaf_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_9288ba_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_1e1ee6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["subject_identifier", "onschedule_datetime", "site"],
                name="intecomm_pr_subject_2dcd56_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_322d8f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["user_modified", "user_created"], name="intecomm_pr_user_mo_adb6ab_idx"
            ),
        ),
    ]



# Generated by Django 5.0.1 on 2024-02-22 01:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_lists", "0011_accompanied_moneysources_travelmethods"),
    ]

    operations = [
        migrations.AddField(
            model_name="visitreasons",
            name="custom_name",
            field=models.CharField(
                blank=True,
                help_text="A custom name/value to use on export instead of or in addition to `name`",
                max_length=25,
                null=True,
            ),
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-16 20:40

import django.core.validators
import edc_model_fields.fields.custom_django_fields
import edc_model_fields.fields.other_charfield
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0174_remove_careseekinga_care_visit_lost_income_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="careseekinga",
            name="wait_duration",
        ),
        migrations.RemoveField(
            model_name="historicalcareseekinga",
            name="wait_duration",
        ),
        migrations.AddField(
            model_name="careseekingb",
            name="accompany_alt_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                metadata="FOUTACMPACTOTHER1",
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalcareseekingb",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("alone", "No one, I came alone"),
                    ("main_earner", "Main household earner"),
                    ("adult", "Other family member/relatives/friends (adults)"),
                    ("child", "Other family member/relatives/friends (children)"),
                ],
                max_length=25,
                metadata="FOUTACMP1",
                null=True,
                verbose_name="Who accompanied you here today?",
            ),
        ),
        migrations.AddField(
            model_name="historicalcareseekingb",
            name="accompany_alt_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                metadata="FOUTACMPACTOTHER1",
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="tests_not_done_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("unavailable", "Tests were not available and not done"),
                    ("expensive", "Tests were too expensive"),
                    ("unimportant", "Did not think it was important to do these tests "),
                    ("too_busy", "Did not have the time to do these tests"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FTESTNO1",
                verbose_name="Why were the tests not performed?",
            ),
        ),
        migrations.RemoveField(
            model_name="careseekingb",
            name="accompany",
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUTACMPNUM1",
                null=True,
                verbose_name="Number of people who accompanied you to your last/most recent visit",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If NO, STOP and SAVE.",
                max_length=15,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTACTIVITY1",
                null=True,
                verbose_name="If you were not attending the visit, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="outpatient_visits",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUT1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(10),
                ],
                verbose_name="If yes and OUTPATIENT or BOTH, how many outpatient visits in total?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="seek_care_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("inpatient", "Inpatient (stayed overnight for 1 or more nights"),
                    ("both", "Both"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKTYPE1",
                verbose_name="If yes, what type of care was this?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_done",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="select YES even if done elsewhere / another facility",
                max_length=25,
                metadata="FOUTTESTDONE1",
                verbose_name="Were the tests performed?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="tests_not_done_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("unavailable", "Tests were not available and not done"),
                    ("expensive", "Tests were too expensive"),
                    ("unimportant", "Did not think it was important to do these tests "),
                    ("too_busy", "Did not have the time to do these tests"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTTESTNO1",
                verbose_name="Why were the tests not performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="tests_not_done_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("unavailable", "Tests were not available and not done"),
                    ("expensive", "Tests were too expensive"),
                    ("unimportant", "Did not think it was important to do these tests "),
                    ("too_busy", "Did not have the time to do these tests"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FTESTNO1",
                verbose_name="Why were the tests not performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="accompany_num",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUTACMPNUM1",
                null=True,
                verbose_name="Number of people who accompanied you to your last/most recent visit",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If NO, STOP and SAVE.",
                max_length=15,
                verbose_name="Were you admitted as a INPATIENT?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="missed_activities",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    (
                        "paid_work",
                        "Paid work (e.g. full-time employment, small business owners/traders, day jobs, etc.)",
                    ),
                    ("unpaid_work", "Unpaid work (e.g. subsistence farming, housework etc.)"),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTACTIVITY1",
                null=True,
                verbose_name="If you were not attending the visit, what would you have been doing?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="outpatient_visits",
            field=edc_model_fields.fields.custom_django_fields.IntegerField2(
                blank=True,
                metadata="FOUT1",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(10),
                ],
                verbose_name="If yes and OUTPATIENT or BOTH, how many outpatient visits in total?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="seek_care_type",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("outpatient", "Outpatient (includes laboratory testing)"),
                    ("inpatient", "Inpatient (stayed overnight for 1 or more nights"),
                    ("both", "Both"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FSEEKTYPE1",
                verbose_name="If yes, what type of care was this?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_done",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="select YES even if done elsewhere / another facility",
                max_length=25,
                metadata="FOUTTESTDONE1",
                verbose_name="Were the tests performed?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="tests_not_done_reason",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("unavailable", "Tests were not available and not done"),
                    ("expensive", "Tests were too expensive"),
                    ("unimportant", "Did not think it was important to do these tests "),
                    ("too_busy", "Did not have the time to do these tests"),
                    ("OTHER", "Other, please specify ..."),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FOUTTESTNO1",
                verbose_name="Why were the tests not performed?",
            ),
        ),
        migrations.AddField(
            model_name="careseekingb",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("alone", "No one, I came alone"),
                    ("main_earner", "Main household earner"),
                    ("adult", "Other family member/relatives/friends (adults)"),
                    ("child", "Other family member/relatives/friends (children)"),
                ],
                max_length=25,
                metadata="FOUTACMP1",
                null=True,
                verbose_name="Who accompanied you here today?",
            ),
        ),
    ]



from intecomm_consent.consents import cdef_tz_v1

from .subject_screening import SubjectScreening


class SubjectScreeningTz(SubjectScreening):
    consent_definitions = [cdef_tz_v1]

    class Meta:
        proxy = True
        verbose_name = "Subject Screening (Tanzania)"
        verbose_name_plural = "Subject Screening (Tanzania)"



# Generated by Django 4.2.6 on 2023-11-20 11:59
from __future__ import annotations

from typing import TYPE_CHECKING

from django.db import migrations
from django.db.migrations import RunPython
from edc_constants.constants import INCOMPLETE
from edc_he.calculators import convert_to_sq_meters
from edc_utils import get_utcnow
from tqdm import tqdm

if TYPE_CHECKING:
    from decimal import Decimal


def get_calculated_land_surface_area(obj) -> Decimal | None:
    """Returns land surface area converted to m2.

    Reproduced from: edc_he.model_mixins.property_model_mixin
    """
    calculated_land_surface_area = None
    if obj.land_surface_area and obj.land_surface_area_units:
        calculated_land_surface_area = convert_to_sq_meters(
            area=obj.land_surface_area,
            area_units=obj.land_surface_area_units,
        )
    return calculated_land_surface_area


def update_calculated_land_surface_area(apps, schema_editor):
    he_property_model_cls = apps.get_model("intecomm_subject.healtheconomicsproperty")
    qs = he_property_model_cls.objects.all()
    total = qs.count()
    print(f"\nProcessing {total} HE Property CRFs ...")
    for obj in tqdm(qs, total=total):
        if obj.land_surface_area:
            obj.calculated_land_surface_area = get_calculated_land_surface_area(obj)
            obj.modified = get_utcnow()
            obj.user_modified = __name__ if len(__name__) <= 50 else f"{__name__[:46]} ..."

            if obj.site_id < 200:  # Uganda
                obj.crf_status = INCOMPLETE
                migration_comment = (
                    "[CRF marked INCOMPLETE by system at: "
                    f"{obj.modified.strftime('%Y-%m-%dT%H:%M:%SZ')} "
                    f"({__name__}) (see also Redmine ticket #683)]. "
                    "Please review CRF and save."
                )
                obj.crf_status_comments = (
                    f"{obj.crf_status_comments} \n\n{migration_comment}"
                    if obj.crf_status_comments
                    else migration_comment
                )
            obj.save_base(
                update_fields=[
                    "calculated_land_surface_area",
                    "modified",
                    "user_modified",
                    "crf_status",
                    "crf_status_comments",
                ]
            )
    print("Done.")


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0125_healtheconomicsproperty_calculated_land_surface_area_and_more",
        ),
    ]

    operations = [RunPython(update_calculated_land_surface_area)]



from .end_of_study import EndOfStudy
from .loss_to_followup import LossToFollowup
from .offschedule_comm import OffScheduleComm
from .offschedule_inte import OffScheduleInte
from .onschedule_comm import OnScheduleComm
from .onschedule_inte import OnScheduleInte
from .protocol_incident import ProtocolIncident
from .proxy import SubjectLocator
from .subject_transfer import SubjectTransfer



# Generated by Django 5.0.3 on 2024-03-13 22:06

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0152_rename_visit_cost_careseekinga_care_visit_cost_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="careseekinga",
            old_name="visit_duration",
            new_name="care_visit_duration",
        ),
        migrations.RenameField(
            model_name="historicalcareseekinga",
            old_name="visit_duration",
            new_name="care_visit_duration",
        ),
    ]



# Generated by Django 4.2.7 on 2023-12-04 22:19

import edc_utils.date
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0062_auto_20230831_0032"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="consentrefusal",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Consent Refusal",
                "verbose_name_plural": "Consent Refusals",
            },
        ),
        migrations.AlterModelOptions(
            name="healthtalklog",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health talk log",
                "verbose_name_plural": "Health talk logs",
            },
        ),
        migrations.AlterModelOptions(
            name="oldhealthfacility",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Health Facility",
                "verbose_name_plural": "Health Facilities",
            },
        ),
        migrations.AlterModelOptions(
            name="patientcall",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "ordering": ["report_datetime"],
                "verbose_name": "Patient Call",
                "verbose_name_plural": "Patient Calls",
            },
        ),
        migrations.AlterModelOptions(
            name="patientlog",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Patient Log",
                "verbose_name_plural": "Patient Log",
            },
        ),
        migrations.AlterModelOptions(
            name="patientlogreportprinthistory",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Patient Log Report Print History",
                "verbose_name_plural": "Patient Log Report Print History",
            },
        ),
        migrations.AlterModelOptions(
            name="subjectscreening",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Screening",
                "verbose_name_plural": "Subject Screening",
            },
        ),
        migrations.AlterUniqueTogether(
            name="patientlog",
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name="subjectscreening",
            unique_together=set(),
        ),
        migrations.AddField(
            model_name="consentrefusal",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="consentrefusal",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="healthtalklog",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="healthtalklog",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalconsentrefusal",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalconsentrefusal",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealthtalklog",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealthtalklog",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicaloldhealthfacility",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicaloldhealthfacility",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientcall",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientcall",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientlog",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientlog",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientlogug",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalpatientlogug",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreeningug",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreeningug",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="oldhealthfacility",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="oldhealthfacility",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="patientcall",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="patientcall",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="patientlog",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="patientlogreportprinthistory",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="patientlogreportprinthistory",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatientcall",
            name="report_datetime",
            field=models.DateTimeField(db_index=True, default=edc_utils.date.get_utcnow),
        ),
        migrations.AlterField(
            model_name="patientcall",
            name="report_datetime",
            field=models.DateTimeField(db_index=True, default=edc_utils.date.get_utcnow),
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-10 22:16

import edc_model_fields.fields.custom_django_fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "intecomm_subject",
            "0163_historicalcareseekingb_inpatient_money_sources_main_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="careseekinga",
            name="money_source_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Loan from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Loan from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FTODSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="inpatient_money_sources_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Loan from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Loan from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FINSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="careseekingb",
            name="money_source_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Loan from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Loan from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                metadata="FOUTSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="money_source_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Loan from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Loan from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FTODSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="inpatient_money_sources_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Loan from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Loan from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                metadata="FINSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekingb",
            name="money_source_main",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("own_savings", "Own saving (e.g. “loose funds”, bank savings)"),
                    (
                        "family_gift",
                        "Loan from family members that does not need to be repaid",
                    ),
                    ("family_loan", "Loan from family member that needs to be repaid"),
                    (
                        "gift_relative",
                        "Loan from relative/neighbour that does not need to be repaid",
                    ),
                    ("loan_relative", "Loan from relative/neighbour that needs to be repaid"),
                    ("loan_money_lender", "Loan from money lender"),
                    ("loan_bank", "Loan from another source eg bank"),
                    ("community", "Self-help community group"),
                    ("national_insurance", "National health insurance"),
                    ("private_insurance", "Private health insurance"),
                    ("community_insurance", "Community health insurance"),
                    ("waiver", "Government waiver"),
                    (
                        "asset_sale",
                        "Sale of assets (property, livestock, jewellery, household goods, etc)",
                    ),
                    ("OTHER", "Other (specify)"),
                    ("N/A", "Not applicable"),
                ],
                max_length=25,
                metadata="FOUTSOURCEMAIN1",
                verbose_name="Of the various sources that you have just mentioned, what was the main source of payment?",
            ),
        ),
    ]



from edc_model.models import BaseUuidModel

from ..model_mixins import CrfModelMixin, MedicationAdherenceModelMixin


class HivMedicationAdherence(
    MedicationAdherenceModelMixin,
    CrfModelMixin,
    BaseUuidModel,
):
    condition_label = "HIV"

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Medication Adherence (HIV)"
        verbose_name_plural = "Medication Adherence (HIV)"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from edc_reference import site_reference_configs

site_reference_configs.register_from_visit_schedule(
    visit_models={"edc_appointment.appointment": "intecomm_subject.subjectvisit"}
)

configs = {
    "intecomm_subject.clinicalreviewbaseline": [
        "dm_dx",
        "hiv_dx",
        "htn_dx",
    ],
    "intecomm_subject.clinicalreview": [
        "complications",
        "dm_dx",
        "dm_test",
        "hiv_dx",
        "hiv_test",
        "htn_dx",
        "htn_test",
    ],
    "intecomm_subject.medications": ["refill_hiv", "refill_dm", "refill_htn"],
}

for reference_name, fields in configs.items():
    site_reference_configs.add_fields_to_config(reference_name, fields=fields)



# Generated by Django 4.2.1 on 2023-07-06 02:18

import django.db.models.deletion
import django.db.models.manager
import edc_sites.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("intecomm_group", "0014_alter_communitycarelocation_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="patientgroupmeeting",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Patient Group Meeting",
                "verbose_name_plural": "Patient Groups Meeting",
            },
        ),
        migrations.AlterModelManagers(
            name="patientgroupappointment",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="patientgroupmeeting",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name="patientgroupappointment",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
        migrations.AddField(
            model_name="patientgroupmeeting",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.site",
            ),
        ),
    ]
